==> estateplat-common-1.2.3-20180208.064337-27-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfHtfj.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lizhi@gtmap.cn ">lizhi</a>
 * @version 1.0, 2018/2/6
 * @description       新建商品房合同附件
 */
@Table(name = "fcjy_xjspf_htfj")
public class FcjyXjspfHtfj {
    @Id
    private String htfjid;//主键
    private String fjlx;//附件类型(1:标准模板字典，2:开发商模板字典，3：合同)
    private int xh;//序号
    private String bt;//标题
    private String fjyynr;//附件原有内容
    private String txnr;//填写内容
    private String bzmbid;//标准模板ID
    private String kfsmbid;//开发商模板ID
    private String htid;//合同ID

    public String getHtfjid() {
        return htfjid;
    }

    public void setHtfjid(String htfjid) {
        this.htfjid = htfjid;
    }

    public String getFjlx() {
        return fjlx;
    }

    public void setFjlx(String fjlx) {
        this.fjlx = fjlx;
    }

    public int getXh() {
        return xh;
    }

    public void setXh(int xh) {
        this.xh = xh;
    }

    public String getBt() {
        return bt;
    }

    public void setBt(String bt) {
        this.bt = bt;
    }

    public String getFjyynr() {
        return fjyynr;
    }

    public void setFjyynr(String fjyynr) {
        this.fjyynr = fjyynr;
    }

    public String getTxnr() {
        return txnr;
    }

    public void setTxnr(String txnr) {
        this.txnr = txnr;
    }

    public String getBzmbid() {
        return bzmbid;
    }

    public void setBzmbid(String bzmbid) {
        this.bzmbid = bzmbid;
    }

    public String getKfsmbid() {
        return kfsmbid;
    }

    public void setKfsmbid(String kfsmbid) {
        this.kfsmbid = kfsmbid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }
}

==> estateplat-common-1.2.3-20180516.134834-89-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfHtfj.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lizhi@gtmap.cn ">lizhi</a>
 * @version 1.0, 2018/2/6
 * @description       新建商品房合同附件
 */
@Table(name = "fcjy_xjspf_htfj")
public class FcjyXjspfHtfj {
    @Id
    private String htfjid;//主键
    private String fjlx;//附件类型(1:标准模板字典，2:开发商模板字典，3：合同)
    private Integer xh;//序号
    private String bt;//标题
    private String fjyynr;//附件原有内容
    private String txnr;//填写内容
    private String bzmbid;//标准模板ID
    private String kfsmbid;//开发商模板ID
    private String htid;//合同ID

    public String getHtfjid() {
        return htfjid;
    }

    public void setHtfjid(String htfjid) {
        this.htfjid = htfjid;
    }

    public String getFjlx() {
        return fjlx;
    }

    public void setFjlx(String fjlx) {
        this.fjlx = fjlx;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getBt() {
        return bt;
    }

    public void setBt(String bt) {
        this.bt = bt;
    }

    public String getFjyynr() {
        return fjyynr;
    }

    public void setFjyynr(String fjyynr) {
        this.fjyynr = fjyynr;
    }

    public String getTxnr() {
        return txnr;
    }

    public void setTxnr(String txnr) {
        this.txnr = txnr;
    }

    public String getBzmbid() {
        return bzmbid;
    }

    public void setBzmbid(String bzmbid) {
        this.bzmbid = bzmbid;
    }

    public String getKfsmbid() {
        return kfsmbid;
    }

    public void setKfsmbid(String kfsmbid) {
        this.kfsmbid = kfsmbid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }
}
